slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDSolve

Solves the singular value problem.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDSolve(SVD svd)

Collective on svd

### Input Parameter

| svd | - singular value solver context obtained from SVDCreate()

### Options Database Keys

| -svd_view | - print information about the solver used
| -svd_view_mat0 | - view the first matrix (A)
| -svd_view_mat1 | - view the second matrix (B)
| -svd_view_signature | - view the signature matrix (omega)
| -svd_view_vectors | - view the computed singular vectors
| -svd_view_values | - view the computed singular values
| -svd_converged_reason | - print reason for convergence, and number of iterations
| -svd_error_absolute | - print absolute errors of each singular triplet
| -svd_error_relative | - print relative errors of each singular triplet
| -svd_error_norm | - print errors relative to the matrix norms of each singular triplet

### Notes

All the command-line options listed above admit an optional argument specifying the viewer type and options. For instance, use '-svd_view_mat0 binary:amatrix.bin' to save the A matrix to a binary file, '-svd_view_values draw' to draw the computed singular values graphically, or '-svd_error_relative :myerr.m:ascii_matlab' to save the errors in a file that can be executed in Matlab.

### See Also

SVDCreate(), SVDSetUp(), SVDDestroy()

### Level

beginner

### Location

src/svd/interface/svdsolve.c

### Examples

src/svd/tutorials/ex8.c.html
src/svd/tutorials/ex14.c.html
src/svd/tutorials/ex15.c.html
src/svd/tutorials/ex15f.F.html
src/svd/tutorials/ex45.c.html
src/svd/tutorials/ex48.c.html
src/svd/tutorials/ex51.c.html
src/svd/tutorials/ex52.c.html
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages